@@ -6,6 +6,7 @@ namespace Doctrine\Tests\Common\Collections;
 
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
+use Override;
 use PHPUnit\Framework\Attributes\CoversClass;
 
 use function serialize;
@@ -17,7 +18,7 @@ use function unserialize;
 #[CoversClass(ArrayCollection::class)]
 class ArrayCollectionTest extends ArrayCollectionTestCase
 {
-    /** @inheritDoc */
+    #[Override]
     protected function buildCollection(array $elements = []): Collection
     {
         return new ArrayCollection($elements);
