@@ -7,6 +7,7 @@ namespace Doctrine\Tests\Common\Collections\StaticAnalysis;
 use Closure;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
+use Override;
 
 /**
  * @phpstan-template TKey of array-key
@@ -29,7 +30,8 @@ abstract class CustomCollection implements Collection
      *
      * @return Collection<TKey, T>
      */
-    public function filter(Closure $p)
+    #[Override]
+    public function filter(Closure $p): Collection
     {
         return $this->collection->filter($p);
     }
@@ -39,7 +41,8 @@ abstract class CustomCollection implements Collection
      *
      * @phpstan-return array{0: Collection<TKey, T>, 1: Collection<TKey, T>}
      */
-    public function partition(Closure $p)
+    #[Override]
+    public function partition(Closure $p): array
     {
         return $this->collection->partition($p);
     }
